@@ -18,6 +18,10 @@ EC_KEY *MY_EVP_PKEY_get0_EC_KEY(EVP_PKEY *pkey){
   return pkey->pkey.ec;
 }
 
+X509 *MY_X509_STORE_CTX_get0_cert(X509_STORE_CTX *store){
+  return store->cert;
+}
+
 int MY_RSA_set0_key(RSA *r, BIGNUM *n, BIGNUM *e, BIGNUM *d){
   if(n) r->n = n;
   if(e) r->e = e;
